/*
   Copyright (C) 2014-2017 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef REMOVECOLLECTIONJOB_H
#define REMOVECOLLECTIONJOB_H

#include <QObject>
#include <AkonadiCore/Collection>
class KMMainWidget;
class KJob;
class RemoveCollectionJob : public QObject
{
    Q_OBJECT
public:
    explicit RemoveCollectionJob(QObject *parent = nullptr);
    ~RemoveCollectionJob();

    void setMainWidget(KMMainWidget *mainWidget);

    void start();

    void setCurrentFolder(const Akonadi::Collection &currentFolder);

Q_SIGNALS:
    void clearCurrentFolder();

private:
    void slotDelayedRemoveFolder(KJob *job);
    void slotDeletionCollectionResult(KJob *job);

    KMMainWidget *mMainWidget = nullptr;
    Akonadi::Collection mCurrentCollection;
};

#endif // REMOVECOLLECTIONJOB_H
